@@ -1,18 +1,17 @@
 from __future__ import annotations
 
-from ctypes import PYFUNCTYPE, Structure, c_char_p, c_int, py_object
+from ctypes import PYFUNCTYPE, c_char_p, c_int, py_object
 
 from typing_extensions import Annotated
 
-from einspect.structs import struct
+from einspect.structs.deco import Struct
 
 __all__ = ("PyMethodDef", "PyCFunction")
 
 PyCFunction = PYFUNCTYPE(py_object, py_object, py_object)
 
 
-@struct
-class PyMethodDef(Structure):
+class PyMethodDef(Struct):
     ml_name: Annotated[bytes, c_char_p]
     ml_meth: PyCFunction
     ml_flags: Annotated[int, c_int]
